@@ -10,9 +10,9 @@
 
 #include "capitaldivisionasker.h"
 
-#include <klocale.h>
+#include <KLocalizedString>
 
-#include <qradiobutton.h>
+#include <QRadioButton>
  
 #include "map.h"
 
@@ -21,18 +21,18 @@ capitalDivisionAsker::capitalDivisionAsker(QWidget *parent, KGmap *m, QWidget *w
 	init();
 }
 
-bool capitalDivisionAsker::nextBoxAskerQuestionHook(const QString &division, int i, bool isAnswer)
+bool capitalDivisionAsker::nextBoxAskerQuestionHook(const division *div, int i, bool isAnswer)
 {
 	bool b;
 	if (isAnswer)
 	{
-		p_capital = p_map -> getDivisionCapital(division);
-		p_currentAnswer.setQuestion(i18nc("@item:intable column Question, %1 is capital name", "%1", i18nc(p_map -> getFileName().toUtf8(), p_capital.toUtf8())));
-		p_currentAnswer.setCorrectAnswer(i18nc("@option:radio <City> is the capital of...", "%1", i18nc(p_map -> getFileName().toUtf8(), division.toUtf8())));
+		const QString divisionName = div -> getName();
+		p_capital = div -> getCapital();
+		p_currentAnswer.setQuestion(i18nc("@item:intable column Question, %1 is capital name", "%1", p_capital));
+		p_currentAnswer.setCorrectAnswer(i18nc("@option:radio <City> is the capital of...", "%1", divisionName));
 
-		QString capitalName = i18nc(p_map -> getFileName().toUtf8(), p_capital.toUtf8());
-		setQuestion(i18nc("@title:group", p_map->getCapitalToDivisionQuestionPattern().toUtf8(), capitalName));
-		p_radioButtons[i] -> setText(i18nc("@option:radio <City> is the capital of...", "%1", i18nc(p_map -> getFileName().toUtf8(), division.toUtf8())));
+		setQuestion(p_map->getCapitalToDivisionQuestionPattern().subs(p_capital).toString());
+		p_radioButtons[i] -> setText(i18nc("@option:radio <City> is the capital of...", "%1", divisionName));
 		b = true;
 	}
 	else
@@ -44,9 +44,10 @@ bool capitalDivisionAsker::nextBoxAskerQuestionHook(const QString &division, int
 		// Akershus (true)
 		// Buskerud
 		// Hedmark
-		if (p_map -> getDivisionCapital(division) != p_capital)
+		if (div -> getCapital() != p_capital)
 		{
-			p_radioButtons[i] -> setText(i18nc("@option:radio <City> is the capital of...", "%1", i18nc(p_map -> getFileName().toUtf8(), division.toUtf8())));
+			const QString divisionName = div -> getName();
+			p_radioButtons[i] -> setText(i18nc("@option:radio <City> is the capital of...", "%1", divisionName));
 			b = true;
 		}
 		else b = false;
@@ -61,7 +62,5 @@ void capitalDivisionAsker::setAnswerHook(int userSays)
 
 QString capitalDivisionAsker::getQuestionHook() const
 {
-	QString divisionType = i18nc(p_map -> getFileName().toUtf8(), p_map->getDivisionsString().toUtf8());
-	return i18nc("@title", p_map->getCapitalToDivisionTitle().toUtf8());
-	//return i18nc("@title", p_map->getCapitalToDivisionTitle().toUtf8(), divisionType);
+	return p_map->getCapitalToDivisionTitle();
 }
