@@ -88,10 +88,9 @@ int IntegerInputDialog::GetInteger(QWidget *parent, const QString &title, const
 		ok = true;
 		ret = dialog.value();
 	}
-	if ( rOK != NULL ) *rOK = ok;
+	if ( rOK != nullptr ) *rOK = ok;
 	return ret;
 
 }
 
-
-
+#include "moc_integerinputdialog.cpp"
